@@ -394,6 +394,10 @@ class AMLPipelineHelper:
         """
         if self.module_loader.is_local(module_name):
             target = target if target is not None else self.config.compute.hdi_dc_target
+            if not self.config.compute.hdi_dc_target:
+                raise Exception(
+                    f"Your HDI component {module_name} is using local version. Please specify hdi_dc_target"
+                )
         else:
             target = (
                 target if target is not None else self.config.compute.hdi_prod_target
@@ -421,11 +425,7 @@ class AMLPipelineHelper:
                 )
             merged_conf.update(new_conf)
 
-        module_instance.runsettings.configure(
-            target=target
-            if target is not None
-            else self.config.compute.hdi_prod_target,
-        )
+        module_instance.runsettings.configure(target=target)
 
         module_instance.runsettings.hdinsight.configure(
             driver_memory=driver_memory
@@ -1410,6 +1410,9 @@ class AMLPipelineHelper:
                 log.error(f"An error occurred, recovery is not successful: {e}")
 
     def _update_hdi_dc_configs(self, pipeline):
+        if not self.config.compute.hdi_dc_target:
+            log.info("This pipeline doesn't involve HDI DC.")
+            return pipeline
         nodes = pipeline._expand_pipeline_nodes()
         graph = defaultdict(list)
         node_mapping = {}
@@ -1428,7 +1431,10 @@ class AMLPipelineHelper:
             if id not in node_mapping:
                 continue
             node = node_mapping[id]
-            if node.runsettings.target == self.config.compute.hdi_dc_target:
+            if (
+                node.type != "ScopeComponent"
+                and node.runsettings.target == self.config.compute.hdi_dc_target
+            ):
                 use_hdi_dc[id] = True
                 continue
             for parent in graph[id]:
@@ -1438,6 +1444,10 @@ class AMLPipelineHelper:
 
         for node in nodes:
             if use_hdi_dc[node._instance_id]:
+                if node.type == "ScopeComponent":
+                    # scope component doesn't need to configure compute target
+                    # output datastore has to be cosmos (ADLSg1), while dc_datastore is ADLSg2
+                    continue
                 self._set_all_outputs_to(
                     node,
                     output_mode=None,
